summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminserterrordialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pminserterrordialog.h')
-rw-r--r--kpovmodeler/pminserterrordialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pminserterrordialog.h b/kpovmodeler/pminserterrordialog.h
index 09eb32dd..fe4a48fe 100644
--- a/kpovmodeler/pminserterrordialog.h
+++ b/kpovmodeler/pminserterrordialog.h
@@ -39,11 +39,11 @@ class PMInsertErrorDialog : public KDialogBase
TQ_OBJECT
public:
/**
* Creates a modal PMInsertErrorDialog with tqparent and name.
*/
PMInsertErrorDialog( int NumberOfObjects, int NumberOfInsertErrors,
const TQStringList& details,
- TQWidget* tqparent = 0, const char* name = 0 );
+ TQWidget* parent = 0, const char* name = 0 );
protected slots:
void slotUser1( );
@@ -39,11 +39,11 @@ class PMInsertErrorDialog : public KDialogBase
public:
/**
- * Creates a modal PMInsertErrorDialog with tqparent and name.
+ * Creates a modal PMInsertErrorDialog with parent and name.
*/
PMInsertErrorDialog( int NumberOfObjects, int NumberOfInsertErrors,